@@ -11,7 +11,7 @@
 #define QT_FEATURE_posix_fallocate -1
 #define QT_FEATURE_qml_debug 1
 #define QT_FEATURE_reduce_exports 1
-#define QT_FEATURE_reduce_relocations -1
+#define QT_FEATURE_reduce_relocations 1
 #define QT_FEATURE_release_tools -1
 #define QT_FEATURE_sql 1
 #define QT_FEATURE_sse2 -1
